@@ -11,8 +11,19 @@ class DataHost(ABC):
     The base class for both data pool and data channel.
     """
 
+    def __init__(self, transform=None):
+        self.transform = transform
+
     @abstractmethod
-    def get_unlabeled_data(self):
+    def get_data(self):
+        pass
+
+    @abstractmethod
+    def get_transform_data(self):
+        pass
+
+    @abstractmethod
+    def get_unlabeled_data(self, transformed=False):
         pass
 
     @abstractmethod
@@ -24,5 +35,13 @@ class DataHost(ABC):
         pass
 
     @abstractmethod
-    def get_labeled_data(self):
+    def get_labeled_data(self, transformed=False):
+        pass
+
+    @abstractmethod
+    def get_labeled_ids(self):
+        pass
+
+    @abstractmethod
+    def get_size(self):
         pass
