@@ -15,7 +15,13 @@ class Channel(DataHost):
     def __init__(self, transform=None):
         super().__init__(transform)
 
-    def get_unlabeled_data(self):
+    def get_data(self):
+        pass
+
+    def get_transform_data(self):
+        pass
+
+    def get_unlabeled_data(self, transformed=False):
         pass
 
     def get_unlabeled_ids(self):
@@ -24,5 +30,11 @@ class Channel(DataHost):
     def label(self, x, y):
         pass
 
-    def get_labeled_data(self):
+    def get_labeled_data(self, transformed=False):
         pass
+
+    def get_labeled_ids(self):
+        pass
+
+    def get_size(self):
+        return 1
