@@ -6,15 +6,19 @@
 from abc import ABC, abstractmethod
 
 
-class Learner(ABC):
+class BaseLearner(ABC):
     """
     Learner: the basic class for learning process.
     """
 
     @abstractmethod
-    def learn(self, data_x, data_y, n_epoch, batch_size, transform):
+    def learn(self, data_x, data_y, n_epoch, batch_size, **kwargs):
         pass
 
     @abstractmethod
-    def infer(self, data, batch_size, is_prob):
+    def infer(self, data, batch_size):
+        pass
+
+    @abstractmethod
+    def infer_proba(self, data, batch_size, n_drop):
         pass
