@@ -16,5 +16,6 @@ class RandomSampling(Strategy):
     def __init__(self, data_host, learner):
         super(RandomSampling, self).__init__(data_host, learner)
 
-    def query(self, number):
-        return np.random.choice(list(self.data_host.get_unlabeled_ids()), number, replace=False)
+    def query(self, n):
+        self.check_query_availability(n)
+        return np.random.choice(list(self.data_host.get_unlabeled_ids()), n, replace=False)
